@@ -111,7 +111,10 @@ class QueenbeeTask(luigi.Task):
         """
         logger = self.get_interface_logger()
         for art in self.input_artifacts:
-            logger.info(f"copying input artifact: {art['name']}...")
+            logger.info(
+                f"{self.__class__.__name__}: copying input artifact {art['name']} from "
+                f"{art['from']} ..."
+            )
             try:
                 _copy_artifacts(art['from'], os.path.join(dst, art['to']))
             except TypeError as e:
@@ -121,6 +124,9 @@ class QueenbeeTask(luigi.Task):
                 raise TypeError(
                     f'Failed to copy input artifact: {art["name"]}\n{e}'
                 )
+        logger.info(
+            f"{self.__class__.__name__}: finished copying artifacts..."
+        )
 
     def _copy_output_artifacts(self, src):
         """Copy output artifacts to project folder.
@@ -130,11 +136,16 @@ class QueenbeeTask(luigi.Task):
         """
         logger = self.get_interface_logger()
         for art in self.output_artifacts:
-            logger.info(f"copying output artifact: {art['name']}...")
+            logger.info(
+                f"{self.__class__.__name__}: copying output artifact {art['name']} "
+                f"to {art['to']} ..."
+            )
             try:
                 _copy_artifacts(os.path.join(src, art['from']), art['to'])
             except Exception:
-                logger.exception(f"Failed to copy output artifact: {art['name']}...")
+                logger.exception(
+                    f"Failed to copy output artifact: {art['name']} to {art['to']} ..."
+                )
 
     def _copy_output_parameters(self, src):
         """Copy output parameters to project folder.
@@ -144,7 +155,10 @@ class QueenbeeTask(luigi.Task):
         """
         logger = self.get_interface_logger()
         for art in self.output_parameters:
-            logger.info(f"copying output parameters: {art['name']}...")
+            logger.info(
+                f"{self.__class__.__name__}: copying output parameters {art['name']} "
+                f"to {art['to']} ..."
+            )
             _copy_artifacts(os.path.join(src, art['from']), art['to'])
 
     @property
@@ -193,7 +207,7 @@ class QueenbeeTask(luigi.Task):
         os.chdir(dst)
 
         self._copy_input_artifacts(dst)
-        logger.info(f'Running {self.__class__.__name__}...')
+        logger.info(f'Started running {self.__class__.__name__}...')
 
         p = subprocess.Popen(
             command, stdout=subprocess.PIPE,
@@ -225,6 +239,7 @@ class QueenbeeTask(luigi.Task):
             # folder is in use or running in debug mode
             # this is a temp folder so not deleting is not a major issue
             pass
+        logger.info(f'Finished running {self.__class__.__name__}...')
 
     @staticmethod
     def load_input_param(input_param):
